@@ -34,6 +34,7 @@
 #define GEDIT_VIEW_FRAME_SEARCH_DIALOG_TIMEOUT (30*1000) /* 30 seconds */
 
 #define MIN_SEARCH_COMPLETION_KEY_LEN	3
+#define SEARCH_POPUP_OFFSET 12
 
 #define GEDIT_VIEW_FRAME_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_VIEW_FRAME, GeditViewFramePrivate))
 
@@ -1081,6 +1082,8 @@ create_search_widget (GeditViewFrame *frame)
 	frame->priv->search_entry = gtk_entry_new ();
 	gtk_widget_show (frame->priv->search_entry);
 
+	gtk_entry_set_width_chars (GTK_ENTRY (frame->priv->search_entry), 25);
+
 	g_signal_connect (frame->priv->search_entry, "populate-popup",
 	                  G_CALLBACK (search_entry_populate_popup),
 	                  frame);
@@ -1261,6 +1264,7 @@ start_interactive_search_real (GeditViewFrame *frame)
 	GtkTextBuffer *buffer;
 	GtkTextMark *mark;
 	GtkTextIter iter;
+	GdkGravity gravity;
 
 	/* FIXME: it enters here twice, why? */
 
@@ -1296,13 +1300,23 @@ start_interactive_search_real (GeditViewFrame *frame)
 
 	frame->priv->search_widget = create_search_widget (frame);
 
+	if (gtk_widget_get_direction (frame->priv->search_entry) == GTK_TEXT_DIR_RTL)
+	{
+		gravity = GDK_GRAVITY_NORTH_WEST;
+	}
+	else
+	{
+		gravity = GDK_GRAVITY_NORTH_EAST;
+	}
+
 	gedit_overlay_add_animated_widget (GEDIT_OVERLAY (frame->priv->overlay),
 	                                   frame->priv->search_widget,
 	                                   300,
 	                                   GEDIT_THEATRICS_CHOREOGRAPHER_EASING_EXPONENTIAL_IN_OUT,
 	                                   GEDIT_THEATRICS_CHOREOGRAPHER_BLOCKING_DOWNSTAGE,
 	                                   GTK_ORIENTATION_VERTICAL,
-	                                   GDK_GRAVITY_SOUTH_WEST);
+	                                   gravity,
+	                                   SEARCH_POPUP_OFFSET);
 
 	init_search_entry (frame);
 
